Current Admin Extensions — django-extensions 0.9.1-beta documentation

### Navigation

- index
- next |
- previous |
- django-extensions 0.9.1-beta documentation »

# Current Admin Extensions

synopsis: | Current Field Extensions

- ForeignKeyAutocompleteAdmin - ForeignKeyAutocompleteAdmin will enable the admin app to show ForeignKey fields with an search input field. The search field is rendered by the ForeignKeySearchInput form widget and uses jQuery to do configureable autocompletion.

You can watch a small demo at Flickr.

### Navigation

- index
- next |
- previous |
- django-extensions 0.9.1-beta documentation »